﻿using BlackBerry.Workspaces.Core;
using BlackBerry.Workspaces.Json;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace BlackBerry.Workspaces.Examples
{
    /// <summary>
    /// Examples of Workspaces .NET SDK Events functionality
    /// </summary>
    class EventsExample
    {
        /// <summary>
        /// Initializes a new ApiSession object and logs in the specified user
        /// </summary>
        /// <param name="workspacesServer">
        /// URL of a Workspaces server
        /// </param>
        /// <param name="userEmail">
        /// Email address of a Workspaces user
        /// </param>
        /// <returns>
        /// An ApiSession object for whick the specified user has been authenticated against.
        /// </returns>
        // START SNIPPET: devGuide1
        #region devGuide1

        public ApiSession InitializeSession (string workspacesServer, string userEmail)
        {
            // create a new ApiSession object
            ApiSession apiSession = new ApiSession(workspacesServer);

            // get a reference to the SignInManager
            ISignInManager signInMgr = apiSession.SignInManager;

            // register our event handler
            signInMgr.SignInCompleted += SignInCompleteEventHandler;

            // login the user using OAuth
            LoginResult loginResult = apiSession.StartSessionWithOAuth(userEmail);

            // return the ApiSession
            return apiSession;
        }

        private void SignInCompleteEventHandler(object sender, EventArgs eventArgs)
        {
            Console.WriteLine("User signin completed");
        }

        #endregion
        // END SNIPPET: devGuide1

        /// <summary>
        /// Example of getting a SessionExpired event
        /// </summary>
        /// <param name="workspacesServer">URL of the Workspaces server</param>
        /// <returns>An initiailized ApiSession object</returns>
        // START SNIPPET: devGuide2
        #region devGuide2

        public ApiSession InitializeSession(string workspacesServer)
        {
            // create a new ApiSession object
            ApiSession apiSession = new ApiSession(workspacesServer);

            // register our event handler
            apiSession.SessionExpired += SessionExpiredEventHandler;

            // return the ApiSession
            return apiSession;
        }

        private void SessionExpiredEventHandler(object sender)
        {
            Console.WriteLine("Session expired");
        }

        #endregion
        // END SNIPPET: devGuide2


        /// <summary>
        /// Example of getting a upload progress event
        /// </summary>
        /// <param name="apiSession">An ApiSession instance</param>
        /// <param name="uploadInfo">Details for the upload</param>
        /// <param name="workspaceId">The target workspace/room id</param>
        /// <param name="destinationName">The name of the file in the workspace</param>
        /// <param name="filename">The source file name</param>
        // START SNIPPET: devGuide3
        #region devGuide3

        public void UploadFile(ApiSession apiSession,
                               SubmitDocumentsVdrJson uploadInfo,
                               int workspaceId,
                               string destinationName,
                               string filename)
        {
            // get the UploadManager
            UploadManager upldMgr = apiSession.GetUploadManager();

            // register our event handler
            upldMgr.OnUploadProgressChanged += OnUploadProgressChangedEventHandler;

            // upload the file
            upldMgr.UploadDocumentToRoom(uploadInfo,
                                         workspaceId,
                                         destinationName,
                                         filename,
                                         null);
        }

        private void OnUploadProgressChangedEventHandler(
                        object sender,
                        IFileRequestData fileRequestData,
                        int progress,
                        UploadStatus status)
        {
            Console.WriteLine("Uploading " + fileRequestData.LocalPath +
                              ", " + progress + " percent complete.");
        }

        #endregion
        // END SNIPPET: devGuide3
    }
}
